@@ -2,11 +2,11 @@
 
 if [ ! -x "$(command -v faketime)" ]; then
   echo "libfaketime not found - skipping $0..."
-  exit 1
+  exit 0
 fi
 
 if [ "$1" = 'actual' ]; then
-  faketime '1912-07-10 04:10' "$CALCURSE" --read-only -D "$DATA_DIR" -n
+  faketime -f '1912-07-10 04:10:00' "$CALCURSE" --read-only -D "$DATA_DIR" -n
 elif [ "$1" = 'expected' ]; then
   cat <<EOD
 next appointment:
