@@ -2,11 +2,12 @@
 
 if [ ! -x "$(command -v faketime)" ]; then
   echo "libfaketime not found - skipping $0..."
-  exit 1
+  exit 0
 fi
 
 if [ "$1" = 'actual' ]; then
-  faketime '2000-01-01 00:00:00' "$CALCURSE" --read-only -D "$DATA_DIR"/ -r400
+  faketime -f '2000-01-01 00:00:00' "$CALCURSE" --read-only -D "$DATA_DIR"/ \
+    -r400
 elif [ "$1" = 'expected' ]; then
   cat <<EOD
 04/07/00:
